
function [out_img] = downSampMaskNBlur(I,Cx, Cy, foveal_radius, middle_radius, blur_margin, MARK_BOUNDARIES)
       
    % Downsampling Factors
    samp1 = 2;
    samp2 = 4;
    
    % Radius margin
    foveal_radius = blur_margin*foveal_radius;
    
    % Create blur masks
    [M, N, ~] = size(I);

    x = 1:1:N;
    y = 1:1:M;

    x = x - Cx;
    y = y - Cy;

    [X, Y] = meshgrid(x, y);

    R = sqrt(X.^2 + Y.^2);

    mask_foveal                     = R./R .* 0;
    mask_foveal(R<foveal_radius)    = 1;

    mask_middle                     = R./R .* 0;
    mask_middle(R<middle_radius)    = 1;
    mask_middle(R<foveal_radius)    = 0;

    mask_outer                      = R./R .* 0;
    mask_outer(R>middle_radius)     = 1;

    mask_mark1                      = R./R .* 1;
    mask_mark1(R<foveal_radius+2)   = 0;
    mask_mark1(R<foveal_radius-2)   = 1;
    mask_mark2                      = R./R .* 1;
    mask_mark2(R<middle_radius+2)   = 0;
    mask_mark2(R<middle_radius-2)   = 1;
    mask_mark = mask_mark1 .* mask_mark2;
    mask_mark = repmat(mask_mark, 1, 1, 3);
    
    mask_centre = ones(size(I(:,:,1)));
    mask_centre(Cy-1:Cy+1,Cx-20:Cx+20) = 0;
    mask_centre(Cy-20:Cy+20,Cx-1:Cx+1) = 0;

    % Apply blur
    I_foveal = zeros(size(I));
    I_middle = zeros(size(I));
    I_outer  = zeros(size(I));

    for i = 1:3
        I_foveal(:,:,i) = I(:,:,i) .* mask_foveal;
        I_middle(:,:,i) = downSamp(I(:,:,i),samp1);
        I_middle(:,:,i) = I_middle(:,:,i) .* mask_middle;
        I_outer(:,:,i) = downSamp(I(:,:,i),samp2);
        I_outer(:,:,i)  = I_outer(:,:,i) .* mask_outer;
    end

    out_img = I_foveal + I_middle + I_outer;
    if MARK_BOUNDARIES == 1
        out_img = out_img .* mask_mark;
    end
    out_img = out_img .* mask_centre;
    
end